from .language_service_http import *
from .checker_pb2 import *
from .task_pb2 import *
from .status_pb2 import *
from .events_pb2 import *
from .runtime_pb2 import *
from .stats_pb2 import *
from .language_service_pb2 import *
from .executor_service_http import *
from .executor_service_pb2 import *
from .deprecated_job_pb2 import *
from .deprecated_report_pb2 import *
from .usage_pb2 import *
from .interactor_pb2 import *
from .language_pb2 import *



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Student(_message.Message):
    __slots__ = ["display_name", "graded_at", "grades", "id", "member_id", "overall_grade", "overall_progress", "updated_at"]
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Grade(_message.Message):
        __slots__ = ["entry_id", "grade", "progress"]
        ENTRY_ID_FIELD_NUMBER: _ClassVar[int]
        GRADE_FIELD_NUMBER: _ClassVar[int]
        PROGRESS_FIELD_NUMBER: _ClassVar[int]
        entry_id: str
        grade: int
        progress: float
        def __init__(self, entry_id: _Optional[str] = ..., progress: _Optional[float] = ..., grade: _Optional[int] = ...) -> None: ...
    BREAKDOWN: Student.Extra
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    GRADED_AT_FIELD_NUMBER: _ClassVar[int]
    GRADES_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    OVERALL_GRADE_FIELD_NUMBER: _ClassVar[int]
    OVERALL_PROGRESS_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN_EXTRA: Student.Extra
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    display_name: str
    graded_at: _timestamp_pb2.Timestamp
    grades: _containers.RepeatedCompositeFieldContainer[Student.Grade]
    id: str
    member_id: str
    overall_grade: int
    overall_progress: float
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., member_id: _Optional[str] = ..., display_name: _Optional[str] = ..., overall_progress: _Optional[float] = ..., overall_grade: _Optional[int] = ..., grades: _Optional[_Iterable[_Union[Student.Grade, _Mapping]]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., graded_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/member_user.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.mailing import email_type_pb2 as eolymp_dot_mailing_dot_email__type__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/community/member_user.proto\x12\x10\x65olymp.community\x1a\x1f\x65olymp/mailing/email_type.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xda\x03\n\x04User\x12\x0e\n\x06issuer\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x10\n\x08nickname\x18\n \x01(\t\x12\x1f\n\x17nickname_change_timeout\x18\x0b \x01(\r\x12\r\n\x05\x65mail\x18\x14 \x01(\t\x12\x16\n\x0e\x65mail_verified\x18\x15 \x01(\x08\x12\x36\n\x13\x65mail_subscriptions\x18\x16 \x03(\x0e\x32\x19.eolymp.mailing.EmailType\x12\x10\n\x08password\x18\x1e \x01(\t\x12\x14\n\x0cpassword_age\x18\x1f \x01(\r\x12\x0c\n\x04name\x18( \x01(\t\x12\x0f\n\x07picture\x18\x32 \x01(\t\x12,\n\x08\x62irthday\x18< \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x63ountry\x18\x46 \x01(\t\x12\x0c\n\x04\x63ity\x18I \x01(\t\x12\x0f\n\x07team_id\x18\x64 \x01(\t\x12\x38\n\x0bpreferences\x18\xa0\x06 \x01(\x0b\x32\".eolymp.community.User.Preferences\x1a@\n\x0bPreferences\x12\x0e\n\x06locale\x18\x01 \x01(\t\x12\x10\n\x08timezone\x18\x02 \x01(\t\x12\x0f\n\x07runtime\x18\n \x01(\tB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.member_user_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _USER._serialized_start=123
  _USER._serialized_end=597
  _USER_PREFERENCES._serialized_start=533
  _USER_PREFERENCES._serialized_end=597
# @@protoc_insertion_point(module_scope)



from eolymp.community import attribute_pb2 as _attribute_pb2
from eolymp.community import member_ghost_pb2 as _member_ghost_pb2
from eolymp.community import member_team_pb2 as _member_team_pb2
from eolymp.community import member_user_pb2 as _member_user_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Member(_message.Message):
    __slots__ = ["active", "attributes", "created_at", "fallback_tier_id", "ghost", "groups", "id", "incomplete", "level", "name", "rank", "rank_lower", "rating", "secret", "stats", "team", "tier_id", "unofficial", "url", "user"]
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Stats(_message.Message):
        __slots__ = ["problems_solved", "streak", "submissions_accepted", "submissions_total"]
        PROBLEMS_SOLVED_FIELD_NUMBER: _ClassVar[int]
        STREAK_FIELD_NUMBER: _ClassVar[int]
        SUBMISSIONS_ACCEPTED_FIELD_NUMBER: _ClassVar[int]
        SUBMISSIONS_TOTAL_FIELD_NUMBER: _ClassVar[int]
        problems_solved: int
        streak: int
        submissions_accepted: int
        submissions_total: int
        def __init__(self, streak: _Optional[int] = ..., problems_solved: _Optional[int] = ..., submissions_accepted: _Optional[int] = ..., submissions_total: _Optional[int] = ...) -> None: ...
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTES: Member.Extra
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    FALLBACK_TIER_ID_FIELD_NUMBER: _ClassVar[int]
    GHOST_FIELD_NUMBER: _ClassVar[int]
    GROUPS: Member.Extra
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    INCOMPLETE_FIELD_NUMBER: _ClassVar[int]
    LEVEL_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    NO_EXTRA: Member.Extra
    RANK_FIELD_NUMBER: _ClassVar[int]
    RANK_LOWER_FIELD_NUMBER: _ClassVar[int]
    RATING_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    STATS: Member.Extra
    STATS_FIELD_NUMBER: _ClassVar[int]
    TEAM_FIELD_NUMBER: _ClassVar[int]
    TIER: Member.Extra
    TIER_ID_FIELD_NUMBER: _ClassVar[int]
    UNOFFICIAL_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    active: bool
    attributes: _containers.RepeatedCompositeFieldContainer[_attribute_pb2.Attribute.Value]
    created_at: _timestamp_pb2.Timestamp
    fallback_tier_id: str
    ghost: _member_ghost_pb2.Ghost
    groups: _containers.RepeatedScalarFieldContainer[str]
    id: str
    incomplete: bool
    level: int
    name: str
    rank: int
    rank_lower: int
    rating: int
    secret: bool
    stats: Member.Stats
    team: _member_team_pb2.Team
    tier_id: str
    unofficial: bool
    url: str
    user: _member_user_pb2.User
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., url: _Optional[str] = ..., rank: _Optional[int] = ..., rank_lower: _Optional[int] = ..., rating: _Optional[int] = ..., level: _Optional[int] = ..., active: bool = ..., incomplete: bool = ..., unofficial: bool = ..., secret: bool = ..., tier_id: _Optional[str] = ..., fallback_tier_id: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., user: _Optional[_Union[_member_user_pb2.User, _Mapping]] = ..., team: _Optional[_Union[_member_team_pb2.Team, _Mapping]] = ..., ghost: _Optional[_Union[_member_ghost_pb2.Ghost, _Mapping]] = ..., stats: _Optional[_Union[Member.Stats, _Mapping]] = ..., groups: _Optional[_Iterable[str]] = ..., attributes: _Optional[_Iterable[_Union[_attribute_pb2.Attribute.Value, _Mapping]]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.universe import plan_pb2 as _plan_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescribePlanInput(_message.Message):
    __slots__ = ["currency", "extra", "locale", "plan_id"]
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    PLAN_ID_FIELD_NUMBER: _ClassVar[int]
    currency: str
    extra: _containers.RepeatedScalarFieldContainer[_plan_pb2.Plan.Extra]
    locale: str
    plan_id: str
    def __init__(self, plan_id: _Optional[str] = ..., locale: _Optional[str] = ..., currency: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_plan_pb2.Plan.Extra, str]]] = ...) -> None: ...

class DescribePlanOutput(_message.Message):
    __slots__ = ["plan"]
    PLAN_FIELD_NUMBER: _ClassVar[int]
    plan: _plan_pb2.Plan
    def __init__(self, plan: _Optional[_Union[_plan_pb2.Plan, _Mapping]] = ...) -> None: ...

class ListPlansInput(_message.Message):
    __slots__ = ["currency", "extra", "locale", "offset", "size"]
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    currency: str
    extra: _containers.RepeatedScalarFieldContainer[_plan_pb2.Plan.Extra]
    locale: str
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., locale: _Optional[str] = ..., currency: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_plan_pb2.Plan.Extra, str]]] = ...) -> None: ...

class ListPlansOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_plan_pb2.Plan]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_plan_pb2.Plan, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/entry_problem.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.atlas import testing_feedback_pb2 as eolymp_dot_atlas_dot_testing__feedback__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/course/entry_problem.proto\x12\reolymp.course\x1a#eolymp/atlas/testing_feedback.proto\"\x96\x01\n\x07Problem\x12\x13\n\x0bproblem_url\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x0c\n\x04\x63ost\x18\n \x01(\r\x12\x14\n\x0csubmit_limit\x18\x14 \x01(\r\x12>\n\x18override_feedback_policy\x18\x15 \x01(\x0e\x32\x1c.eolymp.atlas.FeedbackPolicyB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.entry_problem_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _PROBLEM._serialized_start=90
  _PROBLEM._serialized_end=240
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/asset/asset_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/asset/asset_service.proto\x12\x0c\x65olymp.asset\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\"\xc2\x02\n\x10UploadImageInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x31\n\x04\x63rop\x18\n \x01(\x0b\x32#.eolymp.asset.UploadImageInput.Crop\x12\x31\n\x04size\x18\x0b \x01(\x0b\x32#.eolymp.asset.UploadImageInput.Size\x12\x35\n\x08variants\x18\x14 \x03(\x0b\x32#.eolymp.asset.UploadImageInput.Size\x12\x0c\n\x04\x64\x61ta\x18\x64 \x01(\x0c\x1a%\n\x04Size\x12\r\n\x05width\x18\x01 \x01(\r\x12\x0e\n\x06height\x18\x02 \x01(\r\x1a@\n\x04\x43rop\x12\x0b\n\x03top\x18\x01 \x01(\r\x12\r\n\x05right\x18\x02 \x01(\r\x12\x0e\n\x06\x62ottom\x18\x03 \x01(\r\x12\x0c\n\x04left\x18\x04 \x01(\r\"&\n\x11UploadImageOutput\x12\x11\n\timage_url\x18\x01 \x01(\t\";\n\x0fUploadFileInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x64 \x01(\x0c\"$\n\x10UploadFileOutput\x12\x10\n\x08\x66ile_url\x18\x01 \x01(\t\"<\n\x10UploadAssetInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x64 \x01(\x0c\"&\n\x11UploadAssetOutput\x12\x11\n\tasset_url\x18\x01 \x01(\t\"7\n\x19StartMultipartUploadInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"/\n\x1aStartMultipartUploadOutput\x12\x11\n\tupload_id\x18\x01 \x01(\t\"G\n\x0fUploadPartInput\x12\x11\n\tupload_id\x18\x01 \x01(\t\x12\x13\n\x0bpart_number\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x64 \x01(\x0c\"!\n\x10UploadPartOutput\x12\r\n\x05token\x18\x01 \x01(\t\"\xde\x01\n\x1c\x43ompleteMultipartUploadInput\x12\x11\n\tupload_id\x18\x01 \x01(\t\x12>\n\x05parts\x18\n \x03(\x0b\x32/.eolymp.asset.CompleteMultipartUploadInput.Part\x1ak\n\x04Part\x12\x0e\n\x06number\x18\x01 \x01(\r\x12\r\n\x05token\x18\x02 \x01(\t\x12\x14\n\x0c\x63hecksum_md5\x18\n \x01(\t\x12\x15\n\rchecksum_sha1\x18\x0b \x01(\t\x12\x17\n\x0f\x63hecksum_sha256\x18\x0c \x01(\t\"2\n\x1d\x43ompleteMultipartUploadOutput\x12\x11\n\tasset_url\x18\x01 \x01(\t2\xab\x07\n\x0c\x41ssetService\x12\x8e\x01\n\x0bUploadImage\x12\x1e.eolymp.asset.UploadImageInput\x1a\x1f.eolymp.asset.UploadImageOutput\">\x82\xe3\n\x15\x8a\xe3\n\x11\x61sset:image:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x10\"\x0e/assets/images\x12\x8a\x01\n\nUploadFile\x12\x1d.eolymp.asset.UploadFileInput\x1a\x1e.eolymp.asset.UploadFileOutput\"=\x82\xe3\n\x15\x8a\xe3\n\x11\x61sset:image:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0f\"\r/assets/files\x12\x87\x01\n\x0bUploadAsset\x12\x1e.eolymp.asset.UploadAssetInput\x1a\x1f.eolymp.asset.UploadAssetOutput\"7\x82\xe3\n\x15\x8a\xe3\n\x11\x61sset:asset:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\nd\x82\xd3\xe4\x93\x02\t\"\x07/assets\x12\xa3\x01\n\x14StartMultipartUpload\x12\'.eolymp.asset.StartMultipartUploadInput\x1a(.eolymp.asset.StartMultipartUploadOutput\"8\x82\xe3\n\x15\x8a\xe3\n\x11\x61tlas:asset:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\n\x1a\x08/uploads\x12\x91\x01\n\nUploadPart\x12\x1d.eolymp.asset.UploadPartInput\x1a\x1e.eolymp.asset.UploadPartOutput\"D\x82\xe3\n\x15\x8a\xe3\n\x11\x61tlas:asset:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x16\"\x14/uploads/{upload_id}\x12\xb8\x01\n\x17\x43ompleteMultipartUpload\x12*.eolymp.asset.CompleteMultipartUploadInput\x1a+.eolymp.asset.CompleteMultipartUploadOutput\"D\x82\xe3\n\x15\x8a\xe3\n\x11\x61tlas:asset:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x16\x1a\x14/uploads/{upload_id}B-Z+github.com/eolymp/go-sdk/eolymp/asset;assetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.asset.asset_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/asset;asset'
  _ASSETSERVICE.methods_by_name['UploadImage']._options = None
  _ASSETSERVICE.methods_by_name['UploadImage']._serialized_options = b'\202\343\n\025\212\343\n\021asset:image:write\352\342\n\013\365\342\n\000\000\000@\370\342\nd\202\323\344\223\002\020\"\016/assets/images'
  _ASSETSERVICE.methods_by_name['UploadFile']._options = None
  _ASSETSERVICE.methods_by_name['UploadFile']._serialized_options = b'\202\343\n\025\212\343\n\021asset:image:write\352\342\n\013\365\342\n\000\000\000@\370\342\nd\202\323\344\223\002\017\"\r/assets/files'
  _ASSETSERVICE.methods_by_name['UploadAsset']._options = None
  _ASSETSERVICE.methods_by_name['UploadAsset']._serialized_options = b'\202\343\n\025\212\343\n\021asset:asset:write\352\342\n\013\365\342\n\000\000\000@\370\342\nd\202\323\344\223\002\t\"\007/assets'
  _ASSETSERVICE.methods_by_name['StartMultipartUpload']._options = None
  _ASSETSERVICE.methods_by_name['StartMultipartUpload']._serialized_options = b'\202\343\n\025\212\343\n\021atlas:asset:write\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\n\032\010/uploads'
  _ASSETSERVICE.methods_by_name['UploadPart']._options = None
  _ASSETSERVICE.methods_by_name['UploadPart']._serialized_options = b'\202\343\n\025\212\343\n\021atlas:asset:write\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\026\"\024/uploads/{upload_id}'
  _ASSETSERVICE.methods_by_name['CompleteMultipartUpload']._options = None
  _ASSETSERVICE.methods_by_name['CompleteMultipartUpload']._serialized_options = b'\202\343\n\025\212\343\n\021atlas:asset:write\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\026\032\024/uploads/{upload_id}'
  _UPLOADIMAGEINPUT._serialized_start=150
  _UPLOADIMAGEINPUT._serialized_end=472
  _UPLOADIMAGEINPUT_SIZE._serialized_start=369
  _UPLOADIMAGEINPUT_SIZE._serialized_end=406
  _UPLOADIMAGEINPUT_CROP._serialized_start=408
  _UPLOADIMAGEINPUT_CROP._serialized_end=472
  _UPLOADIMAGEOUTPUT._serialized_start=474
  _UPLOADIMAGEOUTPUT._serialized_end=512
  _UPLOADFILEINPUT._serialized_start=514
  _UPLOADFILEINPUT._serialized_end=573
  _UPLOADFILEOUTPUT._serialized_start=575
  _UPLOADFILEOUTPUT._serialized_end=611
  _UPLOADASSETINPUT._serialized_start=613
  _UPLOADASSETINPUT._serialized_end=673
  _UPLOADASSETOUTPUT._serialized_start=675
  _UPLOADASSETOUTPUT._serialized_end=713
  _STARTMULTIPARTUPLOADINPUT._serialized_start=715
  _STARTMULTIPARTUPLOADINPUT._serialized_end=770
  _STARTMULTIPARTUPLOADOUTPUT._serialized_start=772
  _STARTMULTIPARTUPLOADOUTPUT._serialized_end=819
  _UPLOADPARTINPUT._serialized_start=821
  _UPLOADPARTINPUT._serialized_end=892
  _UPLOADPARTOUTPUT._serialized_start=894
  _UPLOADPARTOUTPUT._serialized_end=927
  _COMPLETEMULTIPARTUPLOADINPUT._serialized_start=930
  _COMPLETEMULTIPARTUPLOADINPUT._serialized_end=1152
  _COMPLETEMULTIPARTUPLOADINPUT_PART._serialized_start=1045
  _COMPLETEMULTIPARTUPLOADINPUT_PART._serialized_end=1152
  _COMPLETEMULTIPARTUPLOADOUTPUT._serialized_start=1154
  _COMPLETEMULTIPARTUPLOADOUTPUT._serialized_end=1204
  _ASSETSERVICE._serialized_start=1207
  _ASSETSERVICE._serialized_end=2146
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/contest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/judge/contest.proto\x12\x0c\x65olymp.judge\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd1\x0f\n\x07\x43ontest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x30\n\x05links\x18\xab\x05 \x03(\x0b\x32 .eolymp.judge.Contest.LinksEntry\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08logo_url\x18\x04 \x01(\t\x12-\n\tstarts_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tstarts_in\x18\x0b \x01(\r\x12+\n\x07\x65nds_at\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x65nds_in\x18\x10 \x01(\r\x12\x10\n\x08\x64uration\x18\x0c \x01(\r\x12,\n\x06status\x18\x14 \x01(\x0e\x32\x1c.eolymp.judge.Contest.Status\x12\x34\n\nvisibility\x18\x1e \x01(\x0e\x32 .eolymp.judge.Contest.Visibility\x12\x19\n\x11join_unofficially\x18! \x01(\x08\x12\x43\n\x12participation_mode\x18\x1f \x01(\x0e\x32\'.eolymp.judge.Contest.ParticipationMode\x12,\n\x06\x66ormat\x18  \x01(\x0e\x32\x1c.eolymp.judge.Contest.Format\x12\x0b\n\x03key\x18( \x01(\t\x12\x15\n\rproblem_count\x18< \x01(\r\x12\x1c\n\x14problem_count_hidden\x18= \x01(\x08\x12\x19\n\x11participant_count\x18> \x01(\r\x12 \n\x18participant_count_hidden\x18? \x01(\x08\x12\x32\n\x0e\x66\x65\x61tured_until\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x08taxonomy\x18h \x01(\x0b\x32\x1e.eolymp.judge.Contest.Taxonomy\x12\x34\n\nappearance\x18\x65 \x01(\x0b\x32 .eolymp.judge.Contest.Appearance\x12\x36\n\x0b\x65nvironment\x18g \x01(\x0b\x32!.eolymp.judge.Contest.Environment\x12.\n\x07upsolve\x18\x66 \x01(\x0b\x32\x1d.eolymp.judge.Contest.Upsolve\x12\x34\n\nscoreboard\x18i \x01(\x0b\x32 .eolymp.judge.Contest.Scoreboard\x1a\x42\n\nAppearance\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x10\n\x08logo_url\x18\x03 \x01(\t\x1a\xf6\x01\n\x08Taxonomy\x12\x0c\n\x04year\x18\x01 \x01(\r\x12\x0e\n\x06series\x18\x02 \x01(\t\x12\x33\n\x05scale\x18\x03 \x01(\x0e\x32$.eolymp.judge.Contest.Taxonomy.Scale\x12\x12\n\ndifficulty\x18\x04 \x01(\r\x12\x0f\n\x07\x63ountry\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x0c\n\x04\x63ity\x18\x07 \x01(\t\"T\n\x05Scale\x12\x11\n\rUNKNOWN_SCALE\x10\x00\x12\t\n\x05LOCAL\x10\x01\x12\x0c\n\x08REGIONAL\x10\x02\x12\x0c\n\x08NATIONAL\x10\x03\x12\x11\n\rINTERNATIONAL\x10\x04\x1a\'\n\x0b\x45nvironment\x12\x18\n\x10\x61llowed_runtimes\x18\x01 \x03(\t\x1a\x38\n\x07Upsolve\x12\x14\n\x0c\x66ree_upsolve\x18\x03 \x01(\x08\x12\x17\n\x0fvirtual_upsolve\x18\x04 \x01(\x08\x1a\xa3\x02\n\nScoreboard\x12?\n\nvisibility\x18\x01 \x01(\x0e\x32+.eolymp.judge.Contest.Scoreboard.Visibility\x12\x15\n\rfreezing_time\x18\x02 \x01(\r\x12\x16\n\x0eunfreeze_delay\x18\x03 \x01(\x05\x12\x17\n\x0f\x61ttempt_penalty\x18\x04 \x01(\r\x12\x13\n\x0btie_breaker\x18\x05 \x01(\t\x12\x15\n\rno_spoiler_ui\x18\x06 \x01(\x08\x12\x11\n\tshare_key\x18\x07 \x01(\t\"M\n\nVisibility\x12\x16\n\x12UNKNOWN_VISIBILITY\x10\x00\x12\r\n\tINVISIBLE\x10\x01\x12\x0c\n\x08INTERNAL\x10\x02\x12\n\n\x06PUBLIC\x10\x03\x1a,\n\nLinksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"^\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\r\n\tSCHEDULED\x10\x01\x12\x08\n\x04OPEN\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\x03\x12\r\n\tSUSPENDED\x10\x04\x12\n\n\x06\x46ROZEN\x10\x05\"K\n\nVisibility\x12\x16\n\x12VISIBILITY_UNKNOWN\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0c\n\x08UNLISTED\x10\x02\x12\x0b\n\x07PRIVATE\x10\x03\"L\n\x11ParticipationMode\x12\x1e\n\x1aPARTICIPATION_MODE_UNKNOWN\x10\x00\x12\n\n\x06ONLINE\x10\x01\x12\x0b\n\x07VIRTUAL\x10\x02\"/\n\x06\x46ormat\x12\x12\n\x0e\x46ORMAT_UNKNOWN\x10\x00\x12\x07\n\x03IOI\x10\x01\x12\x08\n\x04ICPC\x10\x02\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.contest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _CONTEST_LINKSENTRY._options = None
  _CONTEST_LINKSENTRY._serialized_options = b'8\001'
  _CONTEST._serialized_start=78
  _CONTEST._serialized_end=2079
  _CONTEST_APPEARANCE._serialized_start=1025
  _CONTEST_APPEARANCE._serialized_end=1091
  _CONTEST_TAXONOMY._serialized_start=1094
  _CONTEST_TAXONOMY._serialized_end=1340
  _CONTEST_TAXONOMY_SCALE._serialized_start=1256
  _CONTEST_TAXONOMY_SCALE._serialized_end=1340
  _CONTEST_ENVIRONMENT._serialized_start=1342
  _CONTEST_ENVIRONMENT._serialized_end=1381
  _CONTEST_UPSOLVE._serialized_start=1383
  _CONTEST_UPSOLVE._serialized_end=1439
  _CONTEST_SCOREBOARD._serialized_start=1442
  _CONTEST_SCOREBOARD._serialized_end=1733
  _CONTEST_SCOREBOARD_VISIBILITY._serialized_start=1656
  _CONTEST_SCOREBOARD_VISIBILITY._serialized_end=1733
  _CONTEST_LINKSENTRY._serialized_start=1735
  _CONTEST_LINKSENTRY._serialized_end=1779
  _CONTEST_STATUS._serialized_start=1781
  _CONTEST_STATUS._serialized_end=1875
  _CONTEST_VISIBILITY._serialized_start=1877
  _CONTEST_VISIBILITY._serialized_end=1952
  _CONTEST_PARTICIPATIONMODE._serialized_start=1954
  _CONTEST_PARTICIPATIONMODE._serialized_end=2030
  _CONTEST_FORMAT._serialized_start=2032
  _CONTEST_FORMAT._serialized_end=2079
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/submission.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.atlas import testing_feedback_pb2 as eolymp_dot_atlas_dot_testing__feedback__pb2
from eolymp.atlas import testing_scoring_pb2 as eolymp_dot_atlas_dot_testing__scoring__pb2
from eolymp.executor import stats_pb2 as eolymp_dot_executor_dot_stats__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/atlas/submission.proto\x12\x0c\x65olymp.atlas\x1a#eolymp/atlas/testing_feedback.proto\x1a\"eolymp/atlas/testing_scoring.proto\x1a\x1b\x65olymp/executor/stats.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe8\x13\n\nSubmission\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x11\n\tmember_id\x18\x04 \x01(\t\x12\x30\n\x0csubmitted_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04lang\x18\n \x01(\t\x12\x0e\n\x06source\x18\x0b \x01(\t\x12\x12\n\nsource_url\x18\r \x01(\t\x12\x11\n\tsignature\x18\x0c \x01(\t\x12/\n\x06status\x18\x14 \x01(\x0e\x32\x1f.eolymp.atlas.Submission.Status\x12\x31\n\x07verdict\x18\x16 \x01(\x0e\x32 .eolymp.atlas.Submission.Verdict\x12\r\n\x05\x65rror\x18\x15 \x01(\t\x12\x11\n\terror_url\x18\x17 \x01(\t\x12\x0c\n\x04\x63ost\x18\x1e \x01(\x02\x12\r\n\x05score\x18\x1f \x01(\x02\x12\x12\n\npercentage\x18  \x01(\x02\x12\x17\n\x0fwall_time_usage\x18) \x01(\r\x12\x16\n\x0e\x63pu_time_usage\x18* \x01(\r\x12\x14\n\x0cmemory_usage\x18. \x01(\x04\x12\x16\n\x0eresource_usage\x18/ \x01(\x02\x12.\n\x06groups\x18\x32 \x03(\x0b\x32\x1e.eolymp.atlas.Submission.Group\x12\x0e\n\x06\x63ursor\x18\x64 \x01(\t\x1ai\n\x14\x43heckerExecutionData\x12\x0f\n\x07log_url\x18\x01 \x01(\t\x12\x17\n\x0fwall_time_usage\x18\x02 \x01(\r\x12\x14\n\x0cmemory_usage\x18\x03 \x01(\x04\x12\x11\n\texit_code\x18\x04 \x01(\r\x1al\n\x17InteractorExecutionData\x12\x0f\n\x07log_url\x18\x01 \x01(\t\x12\x17\n\x0fwall_time_usage\x18\x02 \x01(\r\x12\x14\n\x0cmemory_usage\x18\x03 \x01(\x04\x12\x11\n\texit_code\x18\x04 \x01(\r\x1a\xde\x06\n\x03Run\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0fwall_time_usage\x18\x02 \x01(\r\x12\x16\n\x0e\x63pu_time_usage\x18\x03 \x01(\r\x12\x14\n\x0cmemory_usage\x18\x04 \x01(\x04\x12\x16\n\x0eresource_usage\x18\x05 \x01(\x02\x12\x12\n\noutput_url\x18\x06 \x01(\t\x12\x12\n\nstderr_url\x18\x07 \x01(\t\x12\r\n\x05index\x18\n \x01(\r\x12\x0f\n\x07test_id\x18\x0b \x01(\t\x12\x0c\n\x04\x63ost\x18\x0c \x01(\x02\x12\r\n\x05score\x18\r \x01(\x02\x12\x33\n\x06status\x18\x14 \x01(\x0e\x32#.eolymp.atlas.Submission.Run.Status\x12\x31\n\x07verdict\x18\x15 \x01(\x0e\x32 .eolymp.atlas.Submission.Verdict\x12%\n\x05stats\x18\x0e \x01(\x0b\x32\x16.eolymp.executor.Stats\x12M\n\x16\x63hecker_execution_data\x18\x1e \x01(\x0b\x32-.eolymp.atlas.Submission.CheckerExecutionData\x12-\n\rchecker_stats\x18\x1f \x01(\x0b\x32\x16.eolymp.executor.Stats\x12S\n\x19interactor_execution_data\x18( \x01(\x0b\x32\x30.eolymp.atlas.Submission.InteractorExecutionData\x12\x30\n\x10interactor_stats\x18) \x01(\x0b\x32\x16.eolymp.executor.Stats\"\xf2\x01\n\x06Status\x12\r\n\tNO_STATUS\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\r\n\tEXECUTING\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\r\x12\x0b\n\x07SKIPPED\x10\n\x12\x0b\n\x07\x42LOCKED\x10\x0b\x12\x16\n\x12VERIFICATION_ERROR\x10\t\x12\x15\n\x11INTERACTION_ERROR\x10\x0c\x12\x0b\n\x07TIMEOUT\x10\x03\x12\x11\n\rCPU_EXHAUSTED\x10\x04\x12\x13\n\x0fMEMORY_OVERFLOW\x10\x05\x12\x10\n\x0cWRONG_ANSWER\x10\x06\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x07\x12\x11\n\rRUNTIME_ERROR\x10\x08\x1a\x9d\x05\n\x05Group\x12\r\n\x05index\x18\x01 \x01(\r\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x35\n\x06status\x18\n \x01(\x0e\x32%.eolymp.atlas.Submission.Group.Status\x12\x31\n\x07verdict\x18\x0c \x01(\x0e\x32 .eolymp.atlas.Submission.Verdict\x12\x14\n\x0c\x64\x65pendencies\x18\x0b \x03(\r\x12\x0c\n\x04\x63ost\x18\x14 \x01(\x02\x12\r\n\x05score\x18\x15 \x01(\x02\x12/\n\x0cscoring_mode\x18\x16 \x01(\x0e\x32\x19.eolymp.atlas.ScoringMode\x12\x35\n\x0f\x66\x65\x65\x64\x62\x61\x63k_policy\x18\x1e \x01(\x0e\x32\x1c.eolymp.atlas.FeedbackPolicy\x12\x17\n\x0fwall_time_usage\x18) \x01(\r\x12\x16\n\x0e\x63pu_time_usage\x18* \x01(\r\x12\x14\n\x0cmemory_usage\x18. \x01(\x04\x12\x16\n\x0eresource_usage\x18/ \x01(\x02\x12*\n\x04runs\x18\x64 \x03(\x0b\x32\x1c.eolymp.atlas.Submission.Run\"\xe0\x01\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x42LOCKED\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0b\n\x07TESTING\x10\x03\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x04\x12\x0b\n\x07TIMEOUT\x10\x05\x12\x11\n\rCPU_EXHAUSTED\x10\x06\x12\x13\n\x0fMEMORY_OVERFLOW\x10\x07\x12\x10\n\x0cWRONG_ANSWER\x10\x08\x12\x11\n\rRUNTIME_ERROR\x10\t\x12\x16\n\x12VERIFICATION_ERROR\x10\n\x12\x0b\n\x07SKIPPED\x10\x0b\x12\x15\n\x11INTERACTION_ERROR\x10\x0c\"_\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0b\n\x07TESTING\x10\x02\x12\x0b\n\x07TIMEOUT\x10\x03\x12\x0c\n\x08\x43OMPLETE\x10\x04\x12\t\n\x05\x45RROR\x10\x05\x12\x0b\n\x07\x46\x41ILURE\x10\x06\"\x8d\x01\n\x07Verdict\x12\x0e\n\nNO_VERDICT\x10\x00\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x01\x12\x10\n\x0cWRONG_ANSWER\x10\x02\x12\x17\n\x13TIME_LIMIT_EXCEEDED\x10\x03\x12\x11\n\rCPU_EXHAUSTED\x10\x04\x12\x13\n\x0fMEMORY_OVERFLOW\x10\x05\x12\x11\n\rRUNTIME_ERROR\x10\x06\x42-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.submission_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _SUBMISSION._serialized_start=183
  _SUBMISSION._serialized_end=2719
  _SUBMISSION_CHECKEREXECUTIONDATA._serialized_start=726
  _SUBMISSION_CHECKEREXECUTIONDATA._serialized_end=831
  _SUBMISSION_INTERACTOREXECUTIONDATA._serialized_start=833
  _SUBMISSION_INTERACTOREXECUTIONDATA._serialized_end=941
  _SUBMISSION_RUN._serialized_start=944
  _SUBMISSION_RUN._serialized_end=1806
  _SUBMISSION_RUN_STATUS._serialized_start=1564
  _SUBMISSION_RUN_STATUS._serialized_end=1806
  _SUBMISSION_GROUP._serialized_start=1809
  _SUBMISSION_GROUP._serialized_end=2478
  _SUBMISSION_GROUP_STATUS._serialized_start=2254
  _SUBMISSION_GROUP_STATUS._serialized_end=2478
  _SUBMISSION_STATUS._serialized_start=2480
  _SUBMISSION_STATUS._serialized_end=2575
  _SUBMISSION_VERDICT._serialized_start=2578
  _SUBMISSION_VERDICT._serialized_end=2719
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/student_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.course import student_pb2 as eolymp_dot_course_dot_student__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/course/student_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1b\x65olymp/course/student.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"W\n\x14\x44\x65scribeStudentInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12,\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1c.eolymp.course.Student.Extra\"@\n\x15\x44\x65scribeStudentOutput\x12\'\n\x07student\x18\x01 \x01(\x0b\x32\x16.eolymp.course.Student\"\x15\n\x13\x44\x65scribeViewerInput\"?\n\x14\x44\x65scribeViewerOutput\x12\'\n\x07student\x18\x01 \x01(\x0b\x32\x16.eolymp.course.Student\"\x80\x03\n\x11ListStudentsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x38\n\x07\x66ilters\x18( \x01(\x0b\x32\'.eolymp.course.ListStudentsInput.Filter\x12\x37\n\x04sort\x18\x32 \x01(\x0e\x32).eolymp.course.ListStudentsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12,\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1c.eolymp.course.Student.Extra\x1ag\n\x06\x46ilter\x12*\n\x02id\x18\n \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x0b \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"\x17\n\x08Sortable\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\"J\n\x12ListStudentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.course.Student\"&\n\x11WatchStudentInput\x12\x11\n\tmember_id\x18\x02 \x01(\t\"=\n\x12WatchStudentOutput\x12\'\n\x07student\x18\x01 \x01(\x0b\x32\x16.eolymp.course.Student2\xda\x04\n\x0eStudentService\x12\xa4\x01\n\x0f\x44\x65scribeStudent\x12#.eolymp.course.DescribeStudentInput\x1a$.eolymp.course.DescribeStudentOutput\"F\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x17\x12\x15/students/{member_id}\x12\x9b\x01\n\x0e\x44\x65scribeViewer\x12\".eolymp.course.DescribeViewerInput\x1a#.eolymp.course.DescribeViewerOutput\"@\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x11\x12\x0f/viewer/student\x12\x8f\x01\n\x0cListStudents\x12 .eolymp.course.ListStudentsInput\x1a!.eolymp.course.ListStudentsOutput\":\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0b\x12\t/students\x12q\n\x0cWatchStudent\x12 .eolymp.course.WatchStudentInput\x1a!.eolymp.course.WatchStudentOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read0\x01\x42/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.student_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _STUDENTSERVICE.methods_by_name['DescribeStudent']._options = None
  _STUDENTSERVICE.methods_by_name['DescribeStudent']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\027\022\025/students/{member_id}'
  _STUDENTSERVICE.methods_by_name['DescribeViewer']._options = None
  _STUDENTSERVICE.methods_by_name['DescribeViewer']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\021\022\017/viewer/student'
  _STUDENTSERVICE.methods_by_name['ListStudents']._options = None
  _STUDENTSERVICE.methods_by_name['ListStudents']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\013\022\t/students'
  _STUDENTSERVICE.methods_by_name['WatchStudent']._options = None
  _STUDENTSERVICE.methods_by_name['WatchStudent']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read'
  _DESCRIBESTUDENTINPUT._serialized_start=251
  _DESCRIBESTUDENTINPUT._serialized_end=338
  _DESCRIBESTUDENTOUTPUT._serialized_start=340
  _DESCRIBESTUDENTOUTPUT._serialized_end=404
  _DESCRIBEVIEWERINPUT._serialized_start=406
  _DESCRIBEVIEWERINPUT._serialized_end=427
  _DESCRIBEVIEWEROUTPUT._serialized_start=429
  _DESCRIBEVIEWEROUTPUT._serialized_end=492
  _LISTSTUDENTSINPUT._serialized_start=495
  _LISTSTUDENTSINPUT._serialized_end=879
  _LISTSTUDENTSINPUT_FILTER._serialized_start=751
  _LISTSTUDENTSINPUT_FILTER._serialized_end=854
  _LISTSTUDENTSINPUT_SORTABLE._serialized_start=856
  _LISTSTUDENTSINPUT_SORTABLE._serialized_end=879
  _LISTSTUDENTSOUTPUT._serialized_start=881
  _LISTSTUDENTSOUTPUT._serialized_end=955
  _WATCHSTUDENTINPUT._serialized_start=957
  _WATCHSTUDENTINPUT._serialized_end=995
  _WATCHSTUDENTOUTPUT._serialized_start=997
  _WATCHSTUDENTOUTPUT._serialized_end=1058
  _STUDENTSERVICE._serialized_start=1061
  _STUDENTSERVICE._serialized_end=1663
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/cognito/quota.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/cognito/quota.proto\x12\x0e\x65olymp.cognito\")\n\x05Quota\x12\r\n\x05value\x18\x01 \x01(\x05\x12\x11\n\tunlimited\x18\x02 \x01(\x08\x42\x31Z/github.com/eolymp/go-sdk/eolymp/cognito;cognitob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.cognito.quota_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/cognito;cognito'
  _QUOTA._serialized_start=46
  _QUOTA._serialized_end=87
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/newsletter/newsletter.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/newsletter/newsletter.proto\x12\x11\x65olymp.newsletter\x1a\x18\x65olymp/ecm/content.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe1\x01\n\nNewsletter\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07subject\x18\x0b \x01(\t\x12$\n\x07\x63ontent\x18\x0c \x01(\x0b\x32\x13.eolymp.ecm.Content\x1a`\n\x0bTranslation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x66 \x01(\t\x12\x0f\n\x07subject\x18g \x01(\t\x12$\n\x07\x63ontent\x18h \x01(\x0b\x32\x13.eolymp.ecm.ContentB7Z5github.com/eolymp/go-sdk/eolymp/newsletter;newsletterb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.newsletter.newsletter_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/newsletter;newsletter'
  _NEWSLETTER._serialized_start=117
  _NEWSLETTER._serialized_end=342
  _NEWSLETTER_TRANSLATION._serialized_start=246
  _NEWSLETTER_TRANSLATION._serialized_end=342
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.atlas import scoring_score_pb2 as _scoring_score_pb2
from eolymp.atlas import submission_pb2 as _submission_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescribeProblemGradingInput(_message.Message):
    __slots__ = ["problem_id"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    def __init__(self, problem_id: _Optional[str] = ...) -> None: ...

class DescribeProblemGradingOutput(_message.Message):
    __slots__ = ["ranges"]
    class Range(_message.Message):
        __slots__ = ["grade", "upper_bound"]
        GRADE_FIELD_NUMBER: _ClassVar[int]
        UPPER_BOUND_FIELD_NUMBER: _ClassVar[int]
        grade: int
        upper_bound: float
        def __init__(self, grade: _Optional[int] = ..., upper_bound: _Optional[float] = ...) -> None: ...
    RANGES_FIELD_NUMBER: _ClassVar[int]
    ranges: _containers.RepeatedCompositeFieldContainer[DescribeProblemGradingOutput.Range]
    def __init__(self, ranges: _Optional[_Iterable[_Union[DescribeProblemGradingOutput.Range, _Mapping]]] = ...) -> None: ...

class DescribeScoreInput(_message.Message):
    __slots__ = ["member_id", "problem_id"]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    member_id: str
    problem_id: str
    def __init__(self, problem_id: _Optional[str] = ..., member_id: _Optional[str] = ...) -> None: ...

class DescribeScoreOutput(_message.Message):
    __slots__ = ["score"]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    score: _scoring_score_pb2.Score
    def __init__(self, score: _Optional[_Union[_scoring_score_pb2.Score, _Mapping]] = ...) -> None: ...

class ListProblemTopInput(_message.Message):
    __slots__ = ["problem_id"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    def __init__(self, problem_id: _Optional[str] = ...) -> None: ...

class ListProblemTopOutput(_message.Message):
    __slots__ = ["items"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_submission_pb2.Submission]
    def __init__(self, items: _Optional[_Iterable[_Union[_submission_pb2.Submission, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class ContestServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def CreateContest(self, request, **kwargs):
        path = "/contests"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.CreateContestOutput"),
            **kwargs,
        )

    def DeleteContest(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DeleteContestOutput"),
            **kwargs,
        )

    def UpdateContest(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.UpdateContestOutput"),
            **kwargs,
        )

    def CopyContest(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/copy"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.CopyContestOutput"),
            **kwargs,
        )

    def DescribeContest(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DescribeContestOutput"),
            **kwargs,
        )

    def ListContests(self, request, **kwargs):
        path = "/contests"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ListContestsOutput"),
            **kwargs,
        )

    def OpenContest(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/open"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.OpenContestOutput"),
            **kwargs,
        )

    def CloseContest(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/close"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.CloseContestOutput"),
            **kwargs,
        )

    def SuspendContest(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/suspend"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.SuspendContestOutput"),
            **kwargs,
        )

    def FreezeContest(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/freeze"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.FreezeContestOutput"),
            **kwargs,
        )

    def ResumeContest(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/resume"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ResumeContestOutput"),
            **kwargs,
        )

    def ListActivities(self, request, **kwargs):
        path = "/contests/"+urllib.parse.quote(request.contest_id)+"/activities"

        # Cleanup URL parameters to avoid any ambiguity
        request.contest_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.ListActivitiesOutput"),
            **kwargs,
        )

    def DescribeContestUsage(self, request, **kwargs):
        path = "/usage/contests"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.judge.DescribeContestUsageOutput"),
            **kwargs,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/helpdesk/auto_reply_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.helpdesk import auto_reply_pb2 as eolymp_dot_helpdesk_dot_auto__reply__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(eolymp/helpdesk/auto_reply_service.proto\x12\x0f\x65olymp.helpdesk\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a eolymp/helpdesk/auto_reply.proto\x1a!eolymp/wellknown/expression.proto\"A\n\x14\x43reateAutoReplyInput\x12)\n\x05reply\x18\x01 \x01(\x0b\x32\x1a.eolymp.helpdesk.AutoReply\")\n\x15\x43reateAutoReplyOutput\x12\x10\n\x08reply_id\x18\x01 \x01(\t\"S\n\x14UpdateAutoReplyInput\x12\x10\n\x08reply_id\x18\x01 \x01(\t\x12)\n\x05reply\x18\x02 \x01(\x0b\x32\x1a.eolymp.helpdesk.AutoReply\"\x17\n\x15UpdateAutoReplyOutput\"(\n\x14\x44\x65leteAutoReplyInput\x12\x10\n\x08reply_id\x18\x01 \x01(\t\"\x17\n\x15\x44\x65leteAutoReplyOutput\"\xfa\x01\n\x14ListAutoRepliesInput\x12\x0e\n\x06render\x18\x01 \x01(\x08\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12=\n\x07\x66ilters\x18( \x01(\x0b\x32,.eolymp.helpdesk.ListAutoRepliesInput.Filter\x1au\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06locale\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"Q\n\x15ListAutoRepliesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12)\n\x05items\x18\x02 \x03(\x0b\x32\x1a.eolymp.helpdesk.AutoReply\":\n\x16\x44\x65scribeAutoReplyInput\x12\x10\n\x08reply_id\x18\x01 \x01(\t\x12\x0e\n\x06render\x18\x02 \x01(\x08\"D\n\x17\x44\x65scribeAutoReplyOutput\x12)\n\x05reply\x18\x01 \x01(\x0b\x32\x1a.eolymp.helpdesk.AutoReply2\xb7\x07\n\x10\x41utoReplyService\x12\xb0\x01\n\x0f\x43reateAutoReply\x12%.eolymp.helpdesk.CreateAutoReplyInput\x1a&.eolymp.helpdesk.CreateAutoReplyOutput\"N\x82\xe3\n\x1d\x8a\xe3\n\x19helpdesk:auto-reply:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x18\"\x16/helpdesk/auto-replies\x12\xbb\x01\n\x0fUpdateAutoReply\x12%.eolymp.helpdesk.UpdateAutoReplyInput\x1a&.eolymp.helpdesk.UpdateAutoReplyOutput\"Y\x82\xe3\n\x1d\x8a\xe3\n\x19helpdesk:auto-reply:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02#\x1a!/helpdesk/auto-replies/{reply_id}\x12\xbb\x01\n\x0f\x44\x65leteAutoReply\x12%.eolymp.helpdesk.DeleteAutoReplyInput\x1a&.eolymp.helpdesk.DeleteAutoReplyOutput\"Y\x82\xe3\n\x1d\x8a\xe3\n\x19helpdesk:auto-reply:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02#*!/helpdesk/auto-replies/{reply_id}\x12\xaf\x01\n\x0fListAutoReplies\x12%.eolymp.helpdesk.ListAutoRepliesInput\x1a&.eolymp.helpdesk.ListAutoRepliesOutput\"M\x82\xe3\n\x1c\x8a\xe3\n\x18helpdesk:auto-reply:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x18\x12\x16/helpdesk/auto-replies\x12\xc1\x01\n\x11\x44\x65scribeAutoReply\x12\'.eolymp.helpdesk.DescribeAutoReplyInput\x1a(.eolymp.helpdesk.DescribeAutoReplyOutput\"Y\x82\xe3\n\x1d\x8a\xe3\n\x19helpdesk:auto-reply:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02#\x12!/helpdesk/auto-replies/{reply_id}B3Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdeskb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.helpdesk.auto_reply_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdesk'
  _AUTOREPLYSERVICE.methods_by_name['CreateAutoReply']._options = None
  _AUTOREPLYSERVICE.methods_by_name['CreateAutoReply']._serialized_options = b'\202\343\n\035\212\343\n\031helpdesk:auto-reply:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\030\"\026/helpdesk/auto-replies'
  _AUTOREPLYSERVICE.methods_by_name['UpdateAutoReply']._options = None
  _AUTOREPLYSERVICE.methods_by_name['UpdateAutoReply']._serialized_options = b'\202\343\n\035\212\343\n\031helpdesk:auto-reply:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002#\032!/helpdesk/auto-replies/{reply_id}'
  _AUTOREPLYSERVICE.methods_by_name['DeleteAutoReply']._options = None
  _AUTOREPLYSERVICE.methods_by_name['DeleteAutoReply']._serialized_options = b'\202\343\n\035\212\343\n\031helpdesk:auto-reply:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002#*!/helpdesk/auto-replies/{reply_id}'
  _AUTOREPLYSERVICE.methods_by_name['ListAutoReplies']._options = None
  _AUTOREPLYSERVICE.methods_by_name['ListAutoReplies']._serialized_options = b'\202\343\n\034\212\343\n\030helpdesk:auto-reply:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\030\022\026/helpdesk/auto-replies'
  _AUTOREPLYSERVICE.methods_by_name['DescribeAutoReply']._options = None
  _AUTOREPLYSERVICE.methods_by_name['DescribeAutoReply']._serialized_options = b'\202\343\n\035\212\343\n\031helpdesk:auto-reply:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002#\022!/helpdesk/auto-replies/{reply_id}'
  _CREATEAUTOREPLYINPUT._serialized_start=229
  _CREATEAUTOREPLYINPUT._serialized_end=294
  _CREATEAUTOREPLYOUTPUT._serialized_start=296
  _CREATEAUTOREPLYOUTPUT._serialized_end=337
  _UPDATEAUTOREPLYINPUT._serialized_start=339
  _UPDATEAUTOREPLYINPUT._serialized_end=422
  _UPDATEAUTOREPLYOUTPUT._serialized_start=424
  _UPDATEAUTOREPLYOUTPUT._serialized_end=447
  _DELETEAUTOREPLYINPUT._serialized_start=449
  _DELETEAUTOREPLYINPUT._serialized_end=489
  _DELETEAUTOREPLYOUTPUT._serialized_start=491
  _DELETEAUTOREPLYOUTPUT._serialized_end=514
  _LISTAUTOREPLIESINPUT._serialized_start=517
  _LISTAUTOREPLIESINPUT._serialized_end=767
  _LISTAUTOREPLIESINPUT_FILTER._serialized_start=650
  _LISTAUTOREPLIESINPUT_FILTER._serialized_end=767
  _LISTAUTOREPLIESOUTPUT._serialized_start=769
  _LISTAUTOREPLIESOUTPUT._serialized_end=850
  _DESCRIBEAUTOREPLYINPUT._serialized_start=852
  _DESCRIBEAUTOREPLYINPUT._serialized_end=910
  _DESCRIBEAUTOREPLYOUTPUT._serialized_start=912
  _DESCRIBEAUTOREPLYOUTPUT._serialized_end=980
  _AUTOREPLYSERVICE._serialized_start=983
  _AUTOREPLYSERVICE._serialized_end=1934
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.executor import deprecated_job_pb2 as _deprecated_job_pb2
from eolymp.executor import task_pb2 as _task_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateTaskInput(_message.Message):
    __slots__ = ["job", "task"]
    JOB_FIELD_NUMBER: _ClassVar[int]
    TASK_FIELD_NUMBER: _ClassVar[int]
    job: _deprecated_job_pb2.Job
    task: _task_pb2.Task
    def __init__(self, task: _Optional[_Union[_task_pb2.Task, _Mapping]] = ..., job: _Optional[_Union[_deprecated_job_pb2.Job, _Mapping]] = ...) -> None: ...

class CreateTaskOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.content import fragment_pb2 as _fragment_pb2
from eolymp.content import variant_pb2 as _variant_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateFragmentInput(_message.Message):
    __slots__ = ["fragment"]
    FRAGMENT_FIELD_NUMBER: _ClassVar[int]
    fragment: _fragment_pb2.Fragment
    def __init__(self, fragment: _Optional[_Union[_fragment_pb2.Fragment, _Mapping]] = ...) -> None: ...

class CreateFragmentOutput(_message.Message):
    __slots__ = ["fragment_id"]
    FRAGMENT_ID_FIELD_NUMBER: _ClassVar[int]
    fragment_id: str
    def __init__(self, fragment_id: _Optional[str] = ...) -> None: ...

class CreateVariantInput(_message.Message):
    __slots__ = ["fragment_id", "variant"]
    FRAGMENT_ID_FIELD_NUMBER: _ClassVar[int]
    VARIANT_FIELD_NUMBER: _ClassVar[int]
    fragment_id: str
    variant: _variant_pb2.Variant
    def __init__(self, fragment_id: _Optional[str] = ..., variant: _Optional[_Union[_variant_pb2.Variant, _Mapping]] = ...) -> None: ...

class CreateVariantOutput(_message.Message):
    __slots__ = ["variant_id"]
    VARIANT_ID_FIELD_NUMBER: _ClassVar[int]
    variant_id: str
    def __init__(self, variant_id: _Optional[str] = ...) -> None: ...

class DeleteFragmentInput(_message.Message):
    __slots__ = ["fragment_id"]
    FRAGMENT_ID_FIELD_NUMBER: _ClassVar[int]
    fragment_id: str
    def __init__(self, fragment_id: _Optional[str] = ...) -> None: ...

class DeleteFragmentOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteVariantInput(_message.Message):
    __slots__ = ["fragment_id", "variant_id"]
    FRAGMENT_ID_FIELD_NUMBER: _ClassVar[int]
    VARIANT_ID_FIELD_NUMBER: _ClassVar[int]
    fragment_id: str
    variant_id: str
    def __init__(self, fragment_id: _Optional[str] = ..., variant_id: _Optional[str] = ...) -> None: ...

class DeleteVariantOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeFragmentInput(_message.Message):
    __slots__ = ["extra", "fragment_id"]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    FRAGMENT_ID_FIELD_NUMBER: _ClassVar[int]
    extra: _containers.RepeatedScalarFieldContainer[_fragment_pb2.Fragment.Extra]
    fragment_id: str
    def __init__(self, fragment_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_fragment_pb2.Fragment.Extra, str]]] = ...) -> None: ...

class DescribeFragmentOutput(_message.Message):
    __slots__ = ["fragment"]
    FRAGMENT_FIELD_NUMBER: _ClassVar[int]
    fragment: _fragment_pb2.Fragment
    def __init__(self, fragment: _Optional[_Union[_fragment_pb2.Fragment, _Mapping]] = ...) -> None: ...

class DescribePathInput(_message.Message):
    __slots__ = ["extra", "locale", "path"]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    extra: _containers.RepeatedScalarFieldContainer[_fragment_pb2.Fragment.Extra]
    locale: str
    path: str
    def __init__(self, path: _Optional[str] = ..., locale: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_fragment_pb2.Fragment.Extra, str]]] = ...) -> None: ...

class DescribePathOutput(_message.Message):
    __slots__ = ["fragment"]
    FRAGMENT_FIELD_NUMBER: _ClassVar[int]
    fragment: _fragment_pb2.Fragment
    def __init__(self, fragment: _Optional[_Union[_fragment_pb2.Fragment, _Mapping]] = ...) -> None: ...

class DescribeVariantInput(_message.Message):
    __slots__ = ["extra", "fragment_id", "variant_id"]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    FRAGMENT_ID_FIELD_NUMBER: _ClassVar[int]
    VARIANT_ID_FIELD_NUMBER: _ClassVar[int]
    extra: _containers.RepeatedScalarFieldContainer[_variant_pb2.Variant.Extra]
    fragment_id: str
    variant_id: str
    def __init__(self, fragment_id: _Optional[str] = ..., variant_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_variant_pb2.Variant.Extra, str]]] = ...) -> None: ...

class DescribeVariantOutput(_message.Message):
    __slots__ = ["variant"]
    VARIANT_FIELD_NUMBER: _ClassVar[int]
    variant: _variant_pb2.Variant
    def __init__(self, variant: _Optional[_Union[_variant_pb2.Variant, _Mapping]] = ...) -> None: ...

class ListFragmentsInput(_message.Message):
    __slots__ = ["extra", "filters", "locale", "offset", "order", "size", "sort"]
    class Sort(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Filter(_message.Message):
        __slots__ = ["id", "label", "locale", "path", "query"]
        ID_FIELD_NUMBER: _ClassVar[int]
        LABEL_FIELD_NUMBER: _ClassVar[int]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        PATH_FIELD_NUMBER: _ClassVar[int]
        QUERY_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        label: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        locale: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        path: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        query: str
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., path: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., locale: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., label: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    CREATED_AT: ListFragmentsInput.Sort
    DEFAULT: ListFragmentsInput.Sort
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    PATH: ListFragmentsInput.Sort
    SIZE_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    extra: _containers.RepeatedScalarFieldContainer[_fragment_pb2.Fragment.Extra]
    filters: ListFragmentsInput.Filter
    locale: str
    offset: int
    order: _direction_pb2.Direction
    size: int
    sort: ListFragmentsInput.Sort
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListFragmentsInput.Filter, _Mapping]] = ..., sort: _Optional[_Union[ListFragmentsInput.Sort, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ..., locale: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_fragment_pb2.Fragment.Extra, str]]] = ...) -> None: ...

class ListFragmentsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_fragment_pb2.Fragment]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_fragment_pb2.Fragment, _Mapping]]] = ...) -> None: ...

class ListParentsInput(_message.Message):
    __slots__ = ["extra", "locale", "path"]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    extra: _containers.RepeatedScalarFieldContainer[_fragment_pb2.Fragment.Extra]
    locale: str
    path: str
    def __init__(self, path: _Optional[str] = ..., locale: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_fragment_pb2.Fragment.Extra, str]]] = ...) -> None: ...

class ListParentsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_fragment_pb2.Fragment]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_fragment_pb2.Fragment, _Mapping]]] = ...) -> None: ...

class ListVariantsInput(_message.Message):
    __slots__ = ["extra", "filters", "fragment_id", "offset", "size"]
    class Filter(_message.Message):
        __slots__ = ["id", "locale", "query"]
        ID_FIELD_NUMBER: _ClassVar[int]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        QUERY_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        locale: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        query: str
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., locale: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    FRAGMENT_ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    extra: _containers.RepeatedScalarFieldContainer[_variant_pb2.Variant.Extra]
    filters: ListVariantsInput.Filter
    fragment_id: str
    offset: int
    size: int
    def __init__(self, fragment_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListVariantsInput.Filter, _Mapping]] = ..., extra: _Optional[_Iterable[_Union[_variant_pb2.Variant.Extra, str]]] = ...) -> None: ...

class ListVariantsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_variant_pb2.Variant]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_variant_pb2.Variant, _Mapping]]] = ...) -> None: ...

class UpdateFragmentInput(_message.Message):
    __slots__ = ["fragment", "fragment_id"]
    FRAGMENT_FIELD_NUMBER: _ClassVar[int]
    FRAGMENT_ID_FIELD_NUMBER: _ClassVar[int]
    fragment: _fragment_pb2.Fragment
    fragment_id: str
    def __init__(self, fragment_id: _Optional[str] = ..., fragment: _Optional[_Union[_fragment_pb2.Fragment, _Mapping]] = ...) -> None: ...

class UpdateFragmentOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateVariantInput(_message.Message):
    __slots__ = ["fragment_id", "variant", "variant_id"]
    FRAGMENT_ID_FIELD_NUMBER: _ClassVar[int]
    VARIANT_FIELD_NUMBER: _ClassVar[int]
    VARIANT_ID_FIELD_NUMBER: _ClassVar[int]
    fragment_id: str
    variant: _variant_pb2.Variant
    variant_id: str
    def __init__(self, fragment_id: _Optional[str] = ..., variant_id: _Optional[str] = ..., variant: _Optional[_Union[_variant_pb2.Variant, _Mapping]] = ...) -> None: ...

class UpdateVariantOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.community import attribute_pb2 as _attribute_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescribeRegistrationInput(_message.Message):
    __slots__ = ["contest_id"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    def __init__(self, contest_id: _Optional[str] = ...) -> None: ...

class DescribeRegistrationOutput(_message.Message):
    __slots__ = ["attributes", "values"]
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    attributes: _containers.RepeatedCompositeFieldContainer[_attribute_pb2.Attribute]
    values: _containers.RepeatedCompositeFieldContainer[_attribute_pb2.Attribute.Value]
    def __init__(self, attributes: _Optional[_Iterable[_Union[_attribute_pb2.Attribute, _Mapping]]] = ..., values: _Optional[_Iterable[_Union[_attribute_pb2.Attribute.Value, _Mapping]]] = ...) -> None: ...

class SubmitRegistrationInput(_message.Message):
    __slots__ = ["contest_id", "values"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    values: _containers.RepeatedCompositeFieldContainer[_attribute_pb2.Attribute.Value]
    def __init__(self, contest_id: _Optional[str] = ..., values: _Optional[_Iterable[_Union[_attribute_pb2.Attribute.Value, _Mapping]]] = ...) -> None: ...

class SubmitRegistrationOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RatingPoint(_message.Message):
    __slots__ = ["id", "ref", "target_link", "timestamp", "value"]
    ID_FIELD_NUMBER: _ClassVar[int]
    REF_FIELD_NUMBER: _ClassVar[int]
    TARGET_LINK_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    id: str
    ref: str
    target_link: str
    timestamp: _timestamp_pb2.Timestamp
    value: int
    def __init__(self, id: _Optional[str] = ..., ref: _Optional[str] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., value: _Optional[int] = ..., target_link: _Optional[str] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Status(_message.Message):
    __slots__ = ["agent", "error", "failure", "origin", "reference", "runs", "signature", "type", "version"]
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Run(_message.Message):
        __slots__ = ["checker_exit_code", "checker_log_url", "checker_memory_usage", "checker_wall_time_usage", "cost", "cpu_time_limit", "cpu_time_usage", "exit_code", "interactor_exit_code", "interactor_log_url", "interactor_memory_usage", "interactor_wall_time_usage", "memory_limit", "memory_usage", "output_url", "reference", "score", "signal", "status", "stderr_url", "wall_time_limit", "wall_time_usage"]
        class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
        ACCEPTED: Status.Run.Status
        CHECKER_EXIT_CODE_FIELD_NUMBER: _ClassVar[int]
        CHECKER_LOG_URL_FIELD_NUMBER: _ClassVar[int]
        CHECKER_MEMORY_USAGE_FIELD_NUMBER: _ClassVar[int]
        CHECKER_WALL_TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
        COST_FIELD_NUMBER: _ClassVar[int]
        CPU_EXHAUSTED: Status.Run.Status
        CPU_TIME_LIMIT_FIELD_NUMBER: _ClassVar[int]
        CPU_TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
        EXECUTED: Status.Run.Status
        EXECUTING: Status.Run.Status
        EXIT_CODE_FIELD_NUMBER: _ClassVar[int]
        INTERACTION_FAILURE: Status.Run.Status
        INTERACTOR_EXIT_CODE_FIELD_NUMBER: _ClassVar[int]
        INTERACTOR_LOG_URL_FIELD_NUMBER: _ClassVar[int]
        INTERACTOR_MEMORY_USAGE_FIELD_NUMBER: _ClassVar[int]
        INTERACTOR_WALL_TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
        MEMORY_LIMIT_FIELD_NUMBER: _ClassVar[int]
        MEMORY_OVERFLOW: Status.Run.Status
        MEMORY_USAGE_FIELD_NUMBER: _ClassVar[int]
        NONE: Status.Run.Status
        OUTPUT_URL_FIELD_NUMBER: _ClassVar[int]
        PENDING: Status.Run.Status
        REFERENCE_FIELD_NUMBER: _ClassVar[int]
        RUNTIME_ERROR: Status.Run.Status
        SCORE_FIELD_NUMBER: _ClassVar[int]
        SIGNAL_FIELD_NUMBER: _ClassVar[int]
        SKIPPED: Status.Run.Status
        STATUS_FIELD_NUMBER: _ClassVar[int]
        STDERR_URL_FIELD_NUMBER: _ClassVar[int]
        TIMEOUT: Status.Run.Status
        VERIFICATION_FAILURE: Status.Run.Status
        WALL_TIME_LIMIT_FIELD_NUMBER: _ClassVar[int]
        WALL_TIME_USAGE_FIELD_NUMBER: _ClassVar[int]
        WRONG_ANSWER: Status.Run.Status
        checker_exit_code: int
        checker_log_url: str
        checker_memory_usage: int
        checker_wall_time_usage: int
        cost: float
        cpu_time_limit: int
        cpu_time_usage: int
        exit_code: int
        interactor_exit_code: int
        interactor_log_url: str
        interactor_memory_usage: int
        interactor_wall_time_usage: int
        memory_limit: int
        memory_usage: int
        output_url: str
        reference: str
        score: float
        signal: int
        status: Status.Run.Status
        stderr_url: str
        wall_time_limit: int
        wall_time_usage: int
        def __init__(self, reference: _Optional[str] = ..., status: _Optional[_Union[Status.Run.Status, str]] = ..., score: _Optional[float] = ..., cost: _Optional[float] = ..., wall_time_usage: _Optional[int] = ..., wall_time_limit: _Optional[int] = ..., cpu_time_usage: _Optional[int] = ..., cpu_time_limit: _Optional[int] = ..., memory_usage: _Optional[int] = ..., memory_limit: _Optional[int] = ..., exit_code: _Optional[int] = ..., signal: _Optional[int] = ..., output_url: _Optional[str] = ..., stderr_url: _Optional[str] = ..., checker_log_url: _Optional[str] = ..., checker_wall_time_usage: _Optional[int] = ..., checker_memory_usage: _Optional[int] = ..., checker_exit_code: _Optional[int] = ..., interactor_log_url: _Optional[str] = ..., interactor_wall_time_usage: _Optional[int] = ..., interactor_memory_usage: _Optional[int] = ..., interactor_exit_code: _Optional[int] = ...) -> None: ...
    AGENT_FIELD_NUMBER: _ClassVar[int]
    ERROR: Status.Type
    ERROR_FIELD_NUMBER: _ClassVar[int]
    FAILURE: Status.Type
    FAILURE_FIELD_NUMBER: _ClassVar[int]
    NONE: Status.Type
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    RUNS_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    UPDATE: Status.Type
    VERSION_FIELD_NUMBER: _ClassVar[int]
    agent: str
    error: str
    failure: str
    origin: str
    reference: str
    runs: _containers.RepeatedCompositeFieldContainer[Status.Run]
    signature: str
    type: Status.Type
    version: int
    def __init__(self, reference: _Optional[str] = ..., origin: _Optional[str] = ..., type: _Optional[_Union[Status.Type, str]] = ..., error: _Optional[str] = ..., failure: _Optional[str] = ..., runs: _Optional[_Iterable[_Union[Status.Run, _Mapping]]] = ..., signature: _Optional[str] = ..., version: _Optional[int] = ..., agent: _Optional[str] = ...) -> None: ...



from eolymp.atlas import testing_feedback_pb2 as _testing_feedback_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Problem(_message.Message):
    __slots__ = ["cost", "override_feedback_policy", "problem_id", "problem_url", "submit_limit"]
    COST_FIELD_NUMBER: _ClassVar[int]
    OVERRIDE_FEEDBACK_POLICY_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_URL_FIELD_NUMBER: _ClassVar[int]
    SUBMIT_LIMIT_FIELD_NUMBER: _ClassVar[int]
    cost: int
    override_feedback_policy: _testing_feedback_pb2.FeedbackPolicy
    problem_id: str
    problem_url: str
    submit_limit: int
    def __init__(self, problem_url: _Optional[str] = ..., problem_id: _Optional[str] = ..., cost: _Optional[int] = ..., submit_limit: _Optional[int] = ..., override_feedback_policy: _Optional[_Union[_testing_feedback_pb2.FeedbackPolicy, str]] = ...) -> None: ...



from eolymp.commerce import price_pb2 as _price_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Invoice(_message.Message):
    __slots__ = ["amount_due", "amount_paid", "amount_remaining", "created_at", "currency", "customer_id", "description", "discount_amounts", "due_at", "from_invoice", "hosted_invoice_url", "id", "invoice_pdf_url", "items", "number", "status", "subtotal", "subtotal_excluding_tax", "tax", "tax_amounts", "total", "total_excluding_tax"]
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class DiscountAmount(_message.Message):
        __slots__ = ["amount", "discount"]
        AMOUNT_FIELD_NUMBER: _ClassVar[int]
        DISCOUNT_FIELD_NUMBER: _ClassVar[int]
        amount: int
        discount: str
        def __init__(self, amount: _Optional[int] = ..., discount: _Optional[str] = ...) -> None: ...
    class FromInvoice(_message.Message):
        __slots__ = ["invoice", "relation"]
        INVOICE_FIELD_NUMBER: _ClassVar[int]
        RELATION_FIELD_NUMBER: _ClassVar[int]
        invoice: str
        relation: str
        def __init__(self, relation: _Optional[str] = ..., invoice: _Optional[str] = ...) -> None: ...
    class Item(_message.Message):
        __slots__ = ["amount", "amount_excluding_tax", "currency", "description", "discount_amounts", "id", "price", "quantity", "tax_amounts", "unit_amount_excluding_tax"]
        AMOUNT_EXCLUDING_TAX_FIELD_NUMBER: _ClassVar[int]
        AMOUNT_FIELD_NUMBER: _ClassVar[int]
        CURRENCY_FIELD_NUMBER: _ClassVar[int]
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        DISCOUNT_AMOUNTS_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        PRICE_FIELD_NUMBER: _ClassVar[int]
        QUANTITY_FIELD_NUMBER: _ClassVar[int]
        TAX_AMOUNTS_FIELD_NUMBER: _ClassVar[int]
        UNIT_AMOUNT_EXCLUDING_TAX_FIELD_NUMBER: _ClassVar[int]
        amount: int
        amount_excluding_tax: int
        currency: str
        description: str
        discount_amounts: _containers.RepeatedCompositeFieldContainer[Invoice.DiscountAmount]
        id: str
        price: _price_pb2.Price
        quantity: int
        tax_amounts: _containers.RepeatedCompositeFieldContainer[Invoice.TaxAmount]
        unit_amount_excluding_tax: int
        def __init__(self, id: _Optional[str] = ..., description: _Optional[str] = ..., quantity: _Optional[int] = ..., price: _Optional[_Union[_price_pb2.Price, _Mapping]] = ..., currency: _Optional[str] = ..., amount: _Optional[int] = ..., amount_excluding_tax: _Optional[int] = ..., unit_amount_excluding_tax: _Optional[int] = ..., discount_amounts: _Optional[_Iterable[_Union[Invoice.DiscountAmount, _Mapping]]] = ..., tax_amounts: _Optional[_Iterable[_Union[Invoice.TaxAmount, _Mapping]]] = ...) -> None: ...
    class TaxAmount(_message.Message):
        __slots__ = ["amount", "inclusive", "tax_rate", "taxability_reason", "taxable_amount"]
        AMOUNT_FIELD_NUMBER: _ClassVar[int]
        INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
        TAXABILITY_REASON_FIELD_NUMBER: _ClassVar[int]
        TAXABLE_AMOUNT_FIELD_NUMBER: _ClassVar[int]
        TAX_RATE_FIELD_NUMBER: _ClassVar[int]
        amount: int
        inclusive: bool
        tax_rate: str
        taxability_reason: str
        taxable_amount: int
        def __init__(self, amount: _Optional[int] = ..., inclusive: bool = ..., tax_rate: _Optional[str] = ..., taxability_reason: _Optional[str] = ..., taxable_amount: _Optional[int] = ...) -> None: ...
    AMOUNT_DUE_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_PAID_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_REMAINING_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    CURRENCY_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    DISCOUNT_AMOUNTS_FIELD_NUMBER: _ClassVar[int]
    DRAFT: Invoice.Status
    DUE_AT_FIELD_NUMBER: _ClassVar[int]
    FROM_INVOICE_FIELD_NUMBER: _ClassVar[int]
    HOSTED_INVOICE_URL_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    INVOICE_PDF_URL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    OPEN: Invoice.Status
    PAID: Invoice.Status
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SUBTOTAL_EXCLUDING_TAX_FIELD_NUMBER: _ClassVar[int]
    SUBTOTAL_FIELD_NUMBER: _ClassVar[int]
    TAX_AMOUNTS_FIELD_NUMBER: _ClassVar[int]
    TAX_FIELD_NUMBER: _ClassVar[int]
    TOTAL_EXCLUDING_TAX_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    UNCOLLECTIBLE: Invoice.Status
    UNKNOWN_STATUS: Invoice.Status
    VOID: Invoice.Status
    amount_due: int
    amount_paid: int
    amount_remaining: int
    created_at: _timestamp_pb2.Timestamp
    currency: str
    customer_id: str
    description: str
    discount_amounts: _containers.RepeatedCompositeFieldContainer[Invoice.DiscountAmount]
    due_at: _timestamp_pb2.Timestamp
    from_invoice: Invoice.FromInvoice
    hosted_invoice_url: str
    id: str
    invoice_pdf_url: str
    items: _containers.RepeatedCompositeFieldContainer[Invoice.Item]
    number: str
    status: Invoice.Status
    subtotal: int
    subtotal_excluding_tax: int
    tax: int
    tax_amounts: _containers.RepeatedCompositeFieldContainer[Invoice.TaxAmount]
    total: int
    total_excluding_tax: int
    def __init__(self, id: _Optional[str] = ..., number: _Optional[str] = ..., status: _Optional[_Union[Invoice.Status, str]] = ..., customer_id: _Optional[str] = ..., description: _Optional[str] = ..., from_invoice: _Optional[_Union[Invoice.FromInvoice, _Mapping]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., due_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., hosted_invoice_url: _Optional[str] = ..., invoice_pdf_url: _Optional[str] = ..., currency: _Optional[str] = ..., amount_due: _Optional[int] = ..., amount_paid: _Optional[int] = ..., amount_remaining: _Optional[int] = ..., subtotal: _Optional[int] = ..., subtotal_excluding_tax: _Optional[int] = ..., tax_amounts: _Optional[_Iterable[_Union[Invoice.TaxAmount, _Mapping]]] = ..., tax: _Optional[int] = ..., discount_amounts: _Optional[_Iterable[_Union[Invoice.DiscountAmount, _Mapping]]] = ..., total: _Optional[int] = ..., total_excluding_tax: _Optional[int] = ..., items: _Optional[_Iterable[_Union[Invoice.Item, _Mapping]]] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

BRONZE_MEDAL: Medal
DESCRIPTOR: _descriptor.FileDescriptor
GOLD_MEDAL: Medal
HONORABLE_MENTION: Medal
NO_MEDAL: Medal
SILVER_MEDAL: Medal

class Medal(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.discussion import post_type_pb2 as _post_type_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreatePostTypeInput(_message.Message):
    __slots__ = ["type"]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    type: _post_type_pb2.PostType
    def __init__(self, type: _Optional[_Union[_post_type_pb2.PostType, _Mapping]] = ...) -> None: ...

class CreatePostTypeOutput(_message.Message):
    __slots__ = ["type_id"]
    TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    type_id: str
    def __init__(self, type_id: _Optional[str] = ...) -> None: ...

class DeletePostTypeInput(_message.Message):
    __slots__ = ["type_id"]
    TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    type_id: str
    def __init__(self, type_id: _Optional[str] = ...) -> None: ...

class DeletePostTypeOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribePostTypeInput(_message.Message):
    __slots__ = ["extra", "locale", "type_id"]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    extra: _containers.RepeatedScalarFieldContainer[_post_type_pb2.PostType.Extra]
    locale: str
    type_id: str
    def __init__(self, type_id: _Optional[str] = ..., locale: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_post_type_pb2.PostType.Extra, str]]] = ...) -> None: ...

class DescribePostTypeOutput(_message.Message):
    __slots__ = ["type"]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    type: _post_type_pb2.PostType
    def __init__(self, type: _Optional[_Union[_post_type_pb2.PostType, _Mapping]] = ...) -> None: ...

class ListPostTypesInput(_message.Message):
    __slots__ = ["extra", "locale", "offset", "size"]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    extra: _containers.RepeatedScalarFieldContainer[_post_type_pb2.PostType.Extra]
    locale: str
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., locale: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_post_type_pb2.PostType.Extra, str]]] = ...) -> None: ...

class ListPostTypesOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_post_type_pb2.PostType]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_post_type_pb2.PostType, _Mapping]]] = ...) -> None: ...

class UpdatePostTypeInput(_message.Message):
    __slots__ = ["type", "type_id"]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    type: _post_type_pb2.PostType
    type_id: str
    def __init__(self, type_id: _Optional[str] = ..., type: _Optional[_Union[_post_type_pb2.PostType, _Mapping]] = ...) -> None: ...

class UpdatePostTypeOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Quota(_message.Message):
    __slots__ = ["active_contests_per_space", "allow_discussions", "attributes_per_space", "code_templates_per_problem", "contest_upsolve_mode", "contests_per_space", "courses_per_space", "customer_support_reply_time", "dedicated_user_database", "editorial_per_problem", "ghost_participants", "max_contest_duration", "members_per_space", "monthly_contests_per_space", "monthly_evaluations_by_seat", "participants_per_contest", "permissions_per_space", "plagiarism_analysis", "priority_evaluation_queue", "problems_per_contest", "problems_per_space", "scoreboards_per_space", "single_sing_on", "solutions_per_problem", "statement_per_problem", "team_contests", "tests_per_problem", "testset_per_problem", "unofficial_participants"]
    ACTIVE_CONTESTS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
    ALLOW_DISCUSSIONS_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTES_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
    CODE_TEMPLATES_PER_PROBLEM_FIELD_NUMBER: _ClassVar[int]
    CONTESTS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
    CONTEST_UPSOLVE_MODE_FIELD_NUMBER: _ClassVar[int]
    COURSES_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_SUPPORT_REPLY_TIME_FIELD_NUMBER: _ClassVar[int]
    DEDICATED_USER_DATABASE_FIELD_NUMBER: _ClassVar[int]
    EDITORIAL_PER_PROBLEM_FIELD_NUMBER: _ClassVar[int]
    GHOST_PARTICIPANTS_FIELD_NUMBER: _ClassVar[int]
    MAX_CONTEST_DURATION_FIELD_NUMBER: _ClassVar[int]
    MEMBERS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
    MONTHLY_CONTESTS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
    MONTHLY_EVALUATIONS_BY_SEAT_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANTS_PER_CONTEST_FIELD_NUMBER: _ClassVar[int]
    PERMISSIONS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
    PLAGIARISM_ANALYSIS_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_EVALUATION_QUEUE_FIELD_NUMBER: _ClassVar[int]
    PROBLEMS_PER_CONTEST_FIELD_NUMBER: _ClassVar[int]
    PROBLEMS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARDS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
    SINGLE_SING_ON_FIELD_NUMBER: _ClassVar[int]
    SOLUTIONS_PER_PROBLEM_FIELD_NUMBER: _ClassVar[int]
    STATEMENT_PER_PROBLEM_FIELD_NUMBER: _ClassVar[int]
    TEAM_CONTESTS_FIELD_NUMBER: _ClassVar[int]
    TESTSET_PER_PROBLEM_FIELD_NUMBER: _ClassVar[int]
    TESTS_PER_PROBLEM_FIELD_NUMBER: _ClassVar[int]
    UNOFFICIAL_PARTICIPANTS_FIELD_NUMBER: _ClassVar[int]
    active_contests_per_space: int
    allow_discussions: bool
    attributes_per_space: int
    code_templates_per_problem: int
    contest_upsolve_mode: bool
    contests_per_space: int
    courses_per_space: int
    customer_support_reply_time: int
    dedicated_user_database: bool
    editorial_per_problem: int
    ghost_participants: bool
    max_contest_duration: int
    members_per_space: int
    monthly_contests_per_space: int
    monthly_evaluations_by_seat: int
    participants_per_contest: int
    permissions_per_space: int
    plagiarism_analysis: bool
    priority_evaluation_queue: bool
    problems_per_contest: int
    problems_per_space: int
    scoreboards_per_space: int
    single_sing_on: bool
    solutions_per_problem: int
    statement_per_problem: int
    team_contests: bool
    tests_per_problem: int
    testset_per_problem: int
    unofficial_participants: bool
    def __init__(self, permissions_per_space: _Optional[int] = ..., single_sing_on: bool = ..., dedicated_user_database: bool = ..., attributes_per_space: _Optional[int] = ..., customer_support_reply_time: _Optional[int] = ..., allow_discussions: bool = ..., monthly_evaluations_by_seat: _Optional[int] = ..., priority_evaluation_queue: bool = ..., plagiarism_analysis: bool = ..., members_per_space: _Optional[int] = ..., scoreboards_per_space: _Optional[int] = ..., courses_per_space: _Optional[int] = ..., problems_per_space: _Optional[int] = ..., tests_per_problem: _Optional[int] = ..., testset_per_problem: _Optional[int] = ..., statement_per_problem: _Optional[int] = ..., editorial_per_problem: _Optional[int] = ..., solutions_per_problem: _Optional[int] = ..., code_templates_per_problem: _Optional[int] = ..., contests_per_space: _Optional[int] = ..., active_contests_per_space: _Optional[int] = ..., monthly_contests_per_space: _Optional[int] = ..., problems_per_contest: _Optional[int] = ..., participants_per_contest: _Optional[int] = ..., contest_upsolve_mode: bool = ..., max_contest_duration: _Optional[int] = ..., team_contests: bool = ..., ghost_participants: bool = ..., unofficial_participants: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/ranker/activity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/ranker/activity.proto\x12\reolymp.ranker\x1a\x1fgoogle/protobuf/timestamp.proto\"\xef\x03\n\x08\x41\x63tivity\x12\n\n\x02id\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0e\x32\x1c.eolymp.ranker.Activity.Type\x12.\n\x06status\x18\x03 \x01(\x0e\x32\x1e.eolymp.ranker.Activity.Status\x12\x15\n\rscoreboard_id\x18\x05 \x01(\t\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bprogress_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x63omplete_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08progress\x18\x14 \x01(\r\x12\r\n\x05total\x18\x15 \x01(\r\x12\r\n\x05\x65rror\x18\x1e \x01(\t\"(\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\x16\n\x12SCOREBOARD_REBUILD\x10\x01\"H\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07STARTED\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x42/Z-github.com/eolymp/go-sdk/eolymp/ranker;rankerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.ranker.activity_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/ranker;ranker'
  _ACTIVITY._serialized_start=81
  _ACTIVITY._serialized_end=576
  _ACTIVITY_TYPE._serialized_start=462
  _ACTIVITY_TYPE._serialized_end=502
  _ACTIVITY_STATUS._serialized_start=504
  _ACTIVITY_STATUS._serialized_end=576
# @@protoc_insertion_point(module_scope)
